Customisation — OppiaMobile 0.5.2 documentation

# Customisation

This section describes how you can do some basic customisation to the various components of OppiaMobile. Before making any customisations, you should read our page on our use of GitHub - this will help you manage you code and take advantage subsequent developments, bug fixes and new features implemented in the OppiaMobile code.

If you need and help or advice in getting set up and running, or any questions about the platform, then please post on our OppiaMobile Google Groups forum.

- Using GitHub
- OppiaMobile Django Server
  - Prerequisites
  - Getting Started
  - Server Settings
  - Design/Layout
  - Registration Form
  - Data Visualisations
- OppiaMobile Export Block (Moodle)
  - Prerequisites
  - Getting Started
  - Other Activity Types
- Using stylesheets and javascript in your course
  - Creating your own style
- OppiaMobile Android App
  - Prerequisites
  - Getting Started
  - Server Connection
  - Design/Layout
  - Splash Screen
  - Preloading Courses
  - Preloading Media Files
  - Registration Form
  - Other Activity Types
  - Application distribution and auto-updating
- Pre-registration and app distribution
  - How to set up many phones with usernames/courses
  - How to have app auto-update